@@ -133,14 +133,15 @@ class SSHClient(object):
                 output = ""
                 begin=datetime.now()
                 stderr = ""
-                while not channel.closed or channel.recv_ready() or channel.recv_stderr_ready():
+                while True:
                     end = datetime.now()
                     if (end-begin).total_seconds()>timeout:
                         output=""
                         stderr=f"timeout to run cmd.{cmd}"
                     if channel.recv_ready():
-                        output = channel.recv(1024).decode('utf-8', 'ignore')
-                        print(output, end='')
+                        output_chunk  = channel.recv(1024).decode('utf-8', 'ignore')
+                        output += output_chunk
+                        print(output_chunk, end='')
 
                         # 检查输出是否包含预期的提示信息
                         for elem in promt_response:
@@ -150,8 +151,11 @@ class SSHClient(object):
                                 # 发送相应的回答
                                 channel.send(response)
                     if channel.recv_stderr_ready():
-                        stderr=channel.recv_stderr(2024).decode('utf-8', 'ignore')
-
+                        stderr_chunk =channel.recv_stderr(2024).decode('utf-8', 'ignore')
+                        stderr += stderr_chunk
+                        print(stderr_chunk, end='')
+                    if channel.closed and not (channel.recv_ready() or channel.recv_stderr_ready()):
+                        break
                 return_code = channel.recv_exit_status()
                 return ExecResult(return_code, output, stderr)
             else:
